
/*
 *    スタートアップモジュール(ARMv4用)
 */


        /*
         * Vectorテーブルとジャンプテーブル
         * サイズは合計0x3c
         */
        .section .vector,"a"
        .code 32
        .align 0
        .global vector_table
vector_table:
        ldr pc, reset_vector       /* リセット             */
        ldr pc, undef_vector       /* 未定義命令           */
        ldr pc, swi_vector         /* ソフトウェア割込み   */
        ldr pc, prefech_vector     /* プリフェッチアボード */
        ldr pc, data_abort_vector  /* データアボード       */
        ldr pc, reset_vector
        ldr pc, irq_vector         /* IRQ                  */
        ldr pc, fiq_vector         /* IRQ                  */

/*
 *  ベクターテーブル
 */
reset_vector:
        .long   start
undef_vector:
        .long   undef_exception
swi_vector:
        .long   swi_exception
prefech_vector:
        .long   prefetch_exception
data_abort_vector:
        .long   data_abort_exception
irq_vector:
        .long   irq_exception
fiq_vector:
        .long   fiq_exception



        .text
        .code 32
        .align     0
        .global    start
start:
		mov  r1,  #0x00D3		/* IRQ disable, FIQ disable, SVR mode */
		msr  cpsr, r1

        /*
         * スタックポインタと，フレームポインタの初期化
         */
        ldr  r3, =0x4000FFFC	/* スタック = SRAMのトップ */
        mov  sp, r3
        mov  r11, #0        /* Armモード用フレームポインタ   */



        /*
         *  bssセクションのクリア
         */
start_1:
        ldr  r1, =__bss_start
        ldr  r2, =__bss_end
        cmp  r1,r2
        bhs  start_6
        mov  r0,#0
start_2:
        str  r0,[r1],#4
        cmp  r1, r2
        blo  start_2


	/* メイン関数の呼び出し */
start_6:
        bl    main

	/*
	* エンドレス・ループ
	*/
start_7:
undef_exception:
swi_exception:
prefetch_exception:
data_abort_exception:
irq_exception:
fiq_exception:
	b   start_7

