#include "lpc2388.h"

#define LED1 0x00040000	/* bit18 */
void uart_rx_handler();

int main()
{

		/* Swing SRAM to vector area */
	MEMMAP = 0x02;

		/* PINコンフィグレーション */
	PINSEL0 = 0x50;			/* RD0, TD0 をアサイン */

		/* IOピンをファストIOにする */
	SCS |= 1;

		/* LED1に接続されたピンを出力にする */
	FIO1DIR |= LED1;

		/* LED1を消す */
	FIO1SET  = LED1;	/* H出力（LED1消灯） */

		/* UART 0 初期化 */
	U0LCR = 0x80;		/* DLL,DLMへのアクセスモードに変更 */
	U0DLL = 26;			/* クロックは4MHzを仮定。デフォルトでUARTのPCLK = SYSCLK/4 */
	U0DLM = 0;			/* 4000000/4/(16*26) = 2400[baud] */
	U0LCR = 0x07;		/* 2 stop bit, non parity, 8bit word, DLL,DLM はアクセス不能 */
	U0IER = 1;			/* 受信割り込みをイネーブルにする */

		/* VICの初期化。マニュアルには不要であるように書いているが、実際には必要 */
	VICIntEnClr = 0xFFFFFFFF;	/* すべての割り込みを禁止 */
	VICSoftIntClear = 0xFFFFFFFF;
	VICIntSelect = 0;	/* すべての割り込みをIRQにする */
	VICAddress = 0;		/* レジスタクリア */

		// uart_handlerを登録
	VICVectAddr6 = (unsigned int)uart_rx_handler;
		// 割り込みイネーブル
	VICIntEnable = 0x00000040;	// bit 6 == uart0割り込みをイネーブル


	while(1)
		;				/* 割り込み待ち */

	return 0;
}

void uart_rx_handler()
{
	static int on = 0;		/* LED の状態 */
	int data;				/* 受信データ */


	data = U0RBR;		/* RXデータを読む。割り込みはクリアされるはず */
	U0THR = data;		/* TXにループバック*/

	if (on)
		FIO1SET  = LED1;	/* H出力（LED1消灯） */
	else
		FIO1CLR  = LED1;	/* L出力（LED1点灯） */
	on ^= 1;	/*LED状態を反転*/
}

