#include "lpc2388.h"

#define LED1 0x00040000	/* bit18 */
void timer_handler();
void set_pll();

int main()
{

		/* Swing SRAM to vector area */
	MEMMAP = 0x02;

		/* IOピンをファストIOにする */
	SCS |= 1;

		/* LED1に接続されたピンを出力にする */
	FIO1DIR |= LED1;

		/* LED1を消す */
	FIO1SET  = LED1;	/* H出力（LED1消灯） */


		/* VICの初期化。マニュアルには不要であるように書いているが、実際には必要 */
	VICIntEnClr = 0xFFFFFFFF;	/* すべての割り込みを禁止 */
	VICSoftIntClear = 0xFFFFFFFF;
	VICIntSelect = 0;	/* すべての割り込みをIRQにする */
	VICAddress = 0;		/* レジスタクリア */

	set_pll();

		/* TIMER3の設定　*/
	PCONP |= 1<<23;		/* bit23, TIMER3の電源を入れる　*/
						/* PCLKSEL1.TIMER3は0のまま。PCLK/4をTIMER3のクロックにする */
						/* PIN入出力は変更しない。入力も出力もいらない */
	T3CTCR = 0;			/* PCLKのエッジを数える。キャプチャ入力は無視 */
	T3PR = 0;			/* PCLKのエッジをすべて数える。プリスケールなし */
	T3MR3 = 18000000-1;	/* PCLK=72MHzのとき、TIMERの入力は18MHz。MR3のマッチは1S毎におきる */
	T3MCR = 0x3 << 9;	/* MR3S:R:I = 0:1:1 */

	T3TCR = 1;			/* TIMER3をイネーブルにする */

		// timer_handlerを登録
	VICVectAddr27 = (unsigned int)timer_handler;
		// 割り込みイネーブル
	VICIntEnable = 0x08000000;	// bit 27 == Timer3割り込みをイネーブル


	while(1)
		;				/* 割り込み待ち */

	return 0;
}

void timer_handler()
{
	static int on = 0;		/* LED の状態 */

	T3IR = 1<<3;			/* MR3マッチの割り込みをクリアする */

	if (on)
		FIO1SET  = LED1;	/* H出力（LED1消灯） */
	else
		FIO1CLR  = LED1;	/* L出力（LED1点灯） */
	on ^= 1;	/*LED状態を反転*/
}

void set_pll()
{
	/* 1. もしPLLを使用しているなら、ディスコネクトし、フィード・シーケンスを踏む */
    if ( PLLSTAT & (1 << 25) )
    {
    	PLLCON = 1;				/* Keep PLL Enable disconnected */
    	PLLFEED = 0xAA;
    	PLLFEED = 0x55;
    }

	/* 2. PLLをディセーブルし、フィード・シーケンスを踏む。 */
	PLLCON = 0;		/* Disable PLL */
	PLLFEED = 0xAA;
	PLLFEED = 0x55;

	/* 3. CPUクロック・ディバイダの設定を、PLLなしでも遅くなりすぎないように設定する。 */
	CCLKCFG = 0;	/* CCLK = PCLK / 1 */

	/* 4. PLLのクロックソースを変更する。 */
	CLKSRCSEL = 0;	/* Select 4MHz internal oscillator*/

	/* 5. PLLCFGへの書き込みを行い、フィード・シーケンスを踏んで有効化する。
	 * PLLCFGは、PLLがディセーブルのときにだけ変更できる。 */
	PLLCFG = 35;	/* Divide by 1, Multiply by 72, PCLK = 4*72 = 288MHz */
	PLLFEED = 0xAA;
	PLLFEED = 0x55;

	/* 6. PLLをイネーブルにし、フィード・シーケンスを踏む. */
	PLLCON = 1;		/* Enable PLL */
	PLLFEED = 0xAA;
	PLLFEED = 0x55;

	/* 7. CPUクロック・ディバイダの値を、PLL動作用に変更する。
	 * これは必ず、PLLをクロック源として接続する前に行う。 */
	CCLKCFG = 3;	/* CCLK = PCLK/4 = 288/4 = 72MHz */

	/* 8. PLLSTATレジスタのPLOCK bitを調べて、PLLがロックするまで待つ。
	 * あるいはPLOCK割り込みを使用してもいい。あるいは、PLLの入力クロックが小さい(32kHzなど)なら、
	 * 単純にウェイト・ループを回してもいい。*/
	while ( !(PLLSTAT & (1<<26)))
		;

	/* 9. PLLをシステムに接続し、フィードシーケンスを実行する */
	PLLCON = 3;		/* Select PLL as CPU clock source */
	PLLFEED = 0xAA;
	PLLFEED = 0x55;

}

