#include "lpc2388.h"

#define LED1 0x00040000	/* bit18 */
void timer_handler();

int main()
{
	/* ベクトルリマップ無しの試験なら #if 0にする　*/
#if 1
	volatile unsigned int * flashVector;
	volatile unsigned int * sramVector;
	int i;
		/* ベクトル領域のFLASHの内容をSRAMにコピー */
	flashVector = ( volatile unsigned int * )0x00000000;
	sramVector =  ( volatile unsigned int * )0x40000000;
	for ( i= 0; i< 0x40; i+= sizeof(unsigned int))		/* 0x40は、リマップ領域のサイズ */
	{
		*sramVector = *flashVector;
		sramVector ++;
		flashVector ++;
	}

		/* SRAMをベクトル領域にリマップ */
	MEMMAP = 0x02;
#endif
		/* IOピンをファストIOにする */
	SCS |= 1;

		/* LED1に接続されたピンを出力にする */
	FIO1DIR |= LED1;

		/* LED1を消す */
	FIO1SET  = LED1;	/* H出力（LED1消灯） */


		/* VICの初期化。マニュアルには不要であるように書いているが、実際には必要 */
	VICIntEnClr = 0xFFFFFFFF;	/* すべての割り込みを禁止 */
	VICSoftIntClear = 0xFFFFFFFF;
	VICIntSelect = 0;	/* すべての割り込みをIRQにする */
	VICAddress = 0;		/* レジスタクリア */

		/* TIMER3の設定　*/
	PCONP |= 1<<23;		/* bit23, TIMER3の電源を入れる　*/
						/* PCLKSEL1.TIMER3は0のまま。PCLK/4をTIMER3のクロックにする */
						/* PIN入出力は変更しない。入力も出力もいらない */
	T3CTCR = 0;			/* PCLKのエッジを数える。キャプチャ入力は無視 */
	T3PR = 0;			/* PCLKのエッジをすべて数える。プリスケールなし */
	T3MR3 = 1000000-1;	/* PCLK=4MHzのとき、TIMERの入力は1MHz。MR3のマッチは1S毎におきる */
	T3MCR = 0x3 << 9;	/* MR3S:R:I = 0:1:1, マッチしても停止しない。カウンタをリセットして割り込みを起こす */

	T3TCR = 1;			/* TIMER3をイネーブルにする */

		// timer_handlerを登録
	VICVectAddr27 = (unsigned int)timer_handler;
		// 割り込みイネーブル
	VICIntEnable = 0x08000000;	// bit 27 == Timer3割り込みをイネーブル


	while(1)
		;				/* 割り込み待ち */

	return 0;
}

void timer_handler()
{
	static int on = 0;		/* LED の状態 */

	T3IR = 1<<3;			/* MR3マッチの割り込みをクリアする */

	if (on)
		FIO1SET  = LED1;	/* H出力（LED1消灯） */
	else
		FIO1CLR  = LED1;	/* L出力（LED1点灯） */
	on ^= 1;	/*LED状態を反転*/
}

