
/*
 *    スタートアップモジュール(ARMv4用)
 */

#define SVRSTACK 0x4000FFFC
#define IRQSTACK 0x4000EFFC


        .text
        .code 32
        .align     0
        .global    start
start:
		mov  r1,  #0x00D3		/* IRQ disable, FIQ disable, SVR mode */
		msr  cpsr, r1

        /*
         * SVRモードのスタックポインタと，フレームポインタの初期化
         */
        ldr  sp, =SVRSTACK		/* スタック  */
        mov  r11, #0        	/* Armモード用フレームポインタ   */

        /*
         * IRQモードのスタックポインタと，フレームポインタの初期化
         */
		mov  r1,  #0x00D2		/* IRQ disable, FIQ disable, IRQ mode */
		msr  cpsr, r1

        ldr  sp, =IRQSTACK		/* スタック  */
        mov  r11, #0        	/* Armモード用フレームポインタ   */


        /*
         * SVRモードに戻る。割り込み許可
         */
		mov	r1, #0x0053		/* IRQ Enable, FIQ disable, SVR mode */
		msr	cpsr, r1

        /*
         *  bssセクションのクリア
         *  TOPPERS/JSPの初期化コードを流用
         */
start_1:
        ldr  r1, =__bss_start
        ldr  r2, =__bss_end
        cmp  r1,r2
        bhs  start_3
        mov  r0,#0
start_2:
        str  r0,[r1],#4
        cmp  r1, r2
        blo  start_2

		/*
		 * dataセクションへの初期値のコピー。__idata_startから__idata_endの
		 * 間のデータを__data_startから始まるRAMにコピーする。ROM化対応。
		 * TOPPERS/JSPの初期化コードを流用
		*/
start_3:
        ldr  r1, =__idata_start
        ldr  r3, =__idata_end
        cmp  r1, r3
        bhs  start_6
        ldr  r2, =__data_start
start_4:
        ldr  r0, [r1],#4
        str  r0, [r2],#4
        cmp  r1, r3
        blo  start_4



	/* メイン関数の呼び出し */
start_6:
        bl    main

	/*
	* エンドレス・ループ
	*/
start_7:
	b   start_7


