/*
 *  @(#) $Id: lpc2388_flash.ld,v 1.2 2010-01-13 15:06:00 suikan Exp $
 */

OUTPUT_FORMAT("elf32-littlearm") 
OUTPUT_ARCH(arm)

PROVIDE(hardware_init_hook = 0);
PROVIDE(software_init_hook = 0);
PROVIDE(software_term_hook = 0);

MEMORY
  {
    MEM_FLASH (X!W)	  : ORIGIN = 0x00000000, LENGTH = 512K
    MEM_FIO (W)		  : ORIGIN = 0x3FFF8000, LENGTH = 32K
    MEM_SRAM (XW)     : ORIGIN = 0x40000040, LENGTH = 0xFFC0
    MEM_USBSRAM (XW)  : ORIGIN = 0x7FD00000, LENGTH = 16K
    MEM_ETHERSRAM (XW): ORIGIN = 0x7FE00000, LENGTH = 16K
    MEM_EXTSRAM_0 (XW): ORIGIN = 0x80000000, LENGTH = 64K
    MEM_EXTSRAM_1 (XW): ORIGIN = 0x81000000, LENGTH = 64K
    MEM_SYS (W)		  : ORIGIN = 0xE0000000, LENGTH = 512M
  }


SECTIONS
{
    .text :
    {
    	KEEP(start.o(.vector))
        KEEP(*.o(.text))
    } > MEM_FLASH
    
		/* リードオンリー変数の配置 */
    .rodata : { 
		*(.rodata) 
		*(.rodata.str1.4) 
    } > MEM_FLASH


		/* 初期値付きの変数の配置。初期値はROMに書いておき、変数本体はRAMに配置 */
    . = ALIGN(4);
    __idata_start = . ;					/* 初期値が置かれるFlash ROMのアドレス */
    .data   :  AT(__idata_start) 
    {
        __data_start = . ;				/* 変数が置かれるRAMのアドレス */
        *(.data)
    } > MEM_SRAM
   . = ALIGN(4);
    __idata_end = __idata_start + SIZEOF(.data);
    
	.bss.fiommr (NOLOAD) : { . = 0x0; sys_mmr.o(.MMR0x3FFF8000)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4000; sys_mmr.o(.MMR0x3FFFC000)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4010; sys_mmr.o(.MMR0x3FFFC010)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4014; sys_mmr.o(.MMR0x3FFFC014)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4018; sys_mmr.o(.MMR0x3FFFC018)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x401C; sys_mmr.o(.MMR0x3FFFC01C)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4020; sys_mmr.o(.MMR0x3FFFC020)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4030; sys_mmr.o(.MMR0x3FFFC030)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4034; sys_mmr.o(.MMR0x3FFFC034)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4038; sys_mmr.o(.MMR0x3FFFC038)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x403C; sys_mmr.o(.MMR0x3FFFC03C)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4040; sys_mmr.o(.MMR0x3FFFC040)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4050; sys_mmr.o(.MMR0x3FFFC050)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4054; sys_mmr.o(.MMR0x3FFFC054)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4058; sys_mmr.o(.MMR0x3FFFC058)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x405C; sys_mmr.o(.MMR0x3FFFC05C)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4060; sys_mmr.o(.MMR0x3FFFC060)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4070; sys_mmr.o(.MMR0x3FFFC070)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4074; sys_mmr.o(.MMR0x3FFFC074)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4078; sys_mmr.o(.MMR0x3FFFC078)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x407C; sys_mmr.o(.MMR0x3FFFC07C)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4080; sys_mmr.o(.MMR0x3FFFC080)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4090; sys_mmr.o(.MMR0x3FFFC090)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4094; sys_mmr.o(.MMR0x3FFFC094)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x4098; sys_mmr.o(.MMR0x3FFFC098)} > MEM_FIO
	.bss.fiommr (NOLOAD) : { . = 0x409C; sys_mmr.o(.MMR0x3FFFC09C)} > MEM_FIO


		/* 初期値なしの変数の配置 */
    __bss_start = .	;		
    .bss       :
    {
      *(.bss)
      *(COMMON)
    } > MEM_SRAM
   . = ALIGN(4);
    __bss_end = __bss_start + SIZEOF(.bss);

	.bss.sysmmr (NOLOAD) : { . = 0x0; sys_mmr.o(.MMR0xE0000000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4; sys_mmr.o(.MMR0xE0000004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8; sys_mmr.o(.MMR0xE0000008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0xC; sys_mmr.o(.MMR0xE000000C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x10; sys_mmr.o(.MMR0xE0000010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4000; sys_mmr.o(.MMR0xE0004000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4004; sys_mmr.o(.MMR0xE0004004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4008; sys_mmr.o(.MMR0xE0004008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x400C; sys_mmr.o(.MMR0xE000400C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4010; sys_mmr.o(.MMR0xE0004010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4014; sys_mmr.o(.MMR0xE0004014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4018; sys_mmr.o(.MMR0xE0004018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x401C; sys_mmr.o(.MMR0xE000401C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4020; sys_mmr.o(.MMR0xE0004020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4024; sys_mmr.o(.MMR0xE0004024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4028; sys_mmr.o(.MMR0xE0004028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x402C; sys_mmr.o(.MMR0xE000402C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4030; sys_mmr.o(.MMR0xE0004030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4034; sys_mmr.o(.MMR0xE0004034)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4038; sys_mmr.o(.MMR0xE0004038)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x403C; sys_mmr.o(.MMR0xE000403C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4070; sys_mmr.o(.MMR0xE0004070)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8000; sys_mmr.o(.MMR0xE0008000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8004; sys_mmr.o(.MMR0xE0008004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8008; sys_mmr.o(.MMR0xE0008008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x800C; sys_mmr.o(.MMR0xE000800C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8010; sys_mmr.o(.MMR0xE0008010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8014; sys_mmr.o(.MMR0xE0008014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8018; sys_mmr.o(.MMR0xE0008018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x801C; sys_mmr.o(.MMR0xE000801C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8020; sys_mmr.o(.MMR0xE0008020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8024; sys_mmr.o(.MMR0xE0008024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8028; sys_mmr.o(.MMR0xE0008028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x802C; sys_mmr.o(.MMR0xE000802C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8030; sys_mmr.o(.MMR0xE0008030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8034; sys_mmr.o(.MMR0xE0008034)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8038; sys_mmr.o(.MMR0xE0008038)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x803C; sys_mmr.o(.MMR0xE000803C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8070; sys_mmr.o(.MMR0xE0008070)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0xC000; sys_mmr.o(.MMR0xE000C000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0xC004; sys_mmr.o(.MMR0xE000C004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0xC008; sys_mmr.o(.MMR0xE000C008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0xC00C; sys_mmr.o(.MMR0xE000C00C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0xC014; sys_mmr.o(.MMR0xE000C014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0xC01C; sys_mmr.o(.MMR0xE000C01C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0xC020; sys_mmr.o(.MMR0xE000C020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0xC024; sys_mmr.o(.MMR0xE000C024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0xC028; sys_mmr.o(.MMR0xE000C028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0xC030; sys_mmr.o(.MMR0xE000C030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x10000; sys_mmr.o(.MMR0xE0010000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x10004; sys_mmr.o(.MMR0xE0010004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x10008; sys_mmr.o(.MMR0xE0010008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1000C; sys_mmr.o(.MMR0xE001000C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x10010; sys_mmr.o(.MMR0xE0010010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x10014; sys_mmr.o(.MMR0xE0010014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x10018; sys_mmr.o(.MMR0xE0010018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1001C; sys_mmr.o(.MMR0xE001001C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x10020; sys_mmr.o(.MMR0xE0010020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x10028; sys_mmr.o(.MMR0xE0010028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x10030; sys_mmr.o(.MMR0xE0010030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14000; sys_mmr.o(.MMR0xE0014000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14004; sys_mmr.o(.MMR0xE0014004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14008; sys_mmr.o(.MMR0xE0014008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1400C; sys_mmr.o(.MMR0xE001400C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14010; sys_mmr.o(.MMR0xE0014010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14014; sys_mmr.o(.MMR0xE0014014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14018; sys_mmr.o(.MMR0xE0014018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1401C; sys_mmr.o(.MMR0xE001401C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14020; sys_mmr.o(.MMR0xE0014020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14024; sys_mmr.o(.MMR0xE0014024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14028; sys_mmr.o(.MMR0xE0014028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1402C; sys_mmr.o(.MMR0xE001402C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14030; sys_mmr.o(.MMR0xE0014030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14034; sys_mmr.o(.MMR0xE0014034)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14038; sys_mmr.o(.MMR0xE0014038)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1403C; sys_mmr.o(.MMR0xE001403C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14040; sys_mmr.o(.MMR0xE0014040)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14044; sys_mmr.o(.MMR0xE0014044)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14048; sys_mmr.o(.MMR0xE0014048)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1404C; sys_mmr.o(.MMR0xE001404C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14050; sys_mmr.o(.MMR0xE0014050)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x14070; sys_mmr.o(.MMR0xE0014070)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18000; sys_mmr.o(.MMR0xE0018000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18004; sys_mmr.o(.MMR0xE0018004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18008; sys_mmr.o(.MMR0xE0018008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1800C; sys_mmr.o(.MMR0xE001800C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18010; sys_mmr.o(.MMR0xE0018010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18014; sys_mmr.o(.MMR0xE0018014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18018; sys_mmr.o(.MMR0xE0018018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1801C; sys_mmr.o(.MMR0xE001801C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18020; sys_mmr.o(.MMR0xE0018020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18024; sys_mmr.o(.MMR0xE0018024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18028; sys_mmr.o(.MMR0xE0018028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1802C; sys_mmr.o(.MMR0xE001802C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18030; sys_mmr.o(.MMR0xE0018030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18034; sys_mmr.o(.MMR0xE0018034)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18038; sys_mmr.o(.MMR0xE0018038)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1803C; sys_mmr.o(.MMR0xE001803C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18040; sys_mmr.o(.MMR0xE0018040)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18044; sys_mmr.o(.MMR0xE0018044)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18048; sys_mmr.o(.MMR0xE0018048)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1804C; sys_mmr.o(.MMR0xE001804C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18050; sys_mmr.o(.MMR0xE0018050)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x18070; sys_mmr.o(.MMR0xE0018070)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1C000; sys_mmr.o(.MMR0xE001C000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1C004; sys_mmr.o(.MMR0xE001C004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1C008; sys_mmr.o(.MMR0xE001C008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1C00C; sys_mmr.o(.MMR0xE001C00C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1C010; sys_mmr.o(.MMR0xE001C010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1C014; sys_mmr.o(.MMR0xE001C014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1C018; sys_mmr.o(.MMR0xE001C018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x20000; sys_mmr.o(.MMR0xE0020000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x20004; sys_mmr.o(.MMR0xE0020004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x20008; sys_mmr.o(.MMR0xE0020008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2000C; sys_mmr.o(.MMR0xE002000C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2001C; sys_mmr.o(.MMR0xE002001C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24000; sys_mmr.o(.MMR0xE0024000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24004; sys_mmr.o(.MMR0xE0024004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24008; sys_mmr.o(.MMR0xE0024008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2400C; sys_mmr.o(.MMR0xE002400C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24010; sys_mmr.o(.MMR0xE0024010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24014; sys_mmr.o(.MMR0xE0024014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24018; sys_mmr.o(.MMR0xE0024018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2401C; sys_mmr.o(.MMR0xE002401C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24020; sys_mmr.o(.MMR0xE0024020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24024; sys_mmr.o(.MMR0xE0024024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24028; sys_mmr.o(.MMR0xE0024028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2402C; sys_mmr.o(.MMR0xE002402C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24030; sys_mmr.o(.MMR0xE0024030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24034; sys_mmr.o(.MMR0xE0024034)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24038; sys_mmr.o(.MMR0xE0024038)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2403C; sys_mmr.o(.MMR0xE002403C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24040; sys_mmr.o(.MMR0xE0024040)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24060; sys_mmr.o(.MMR0xE0024060)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24064; sys_mmr.o(.MMR0xE0024064)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24068; sys_mmr.o(.MMR0xE0024068)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2406C; sys_mmr.o(.MMR0xE002406C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24070; sys_mmr.o(.MMR0xE0024070)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24074; sys_mmr.o(.MMR0xE0024074)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24078; sys_mmr.o(.MMR0xE0024078)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2407C; sys_mmr.o(.MMR0xE002407C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24080; sys_mmr.o(.MMR0xE0024080)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x24084; sys_mmr.o(.MMR0xE0024084)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x28000; sys_mmr.o(.MMR0xE0028000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x28004; sys_mmr.o(.MMR0xE0028004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x28008; sys_mmr.o(.MMR0xE0028008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2800C; sys_mmr.o(.MMR0xE002800C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x28010; sys_mmr.o(.MMR0xE0028010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x28014; sys_mmr.o(.MMR0xE0028014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x28018; sys_mmr.o(.MMR0xE0028018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2801C; sys_mmr.o(.MMR0xE002801C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x28080; sys_mmr.o(.MMR0xE0028080)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x28084; sys_mmr.o(.MMR0xE0028084)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x28088; sys_mmr.o(.MMR0xE0028088)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2808C; sys_mmr.o(.MMR0xE002808C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x28090; sys_mmr.o(.MMR0xE0028090)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x28094; sys_mmr.o(.MMR0xE0028094)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x280A4; sys_mmr.o(.MMR0xE00280A4)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x280A8; sys_mmr.o(.MMR0xE00280A8)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x280AC; sys_mmr.o(.MMR0xE00280AC)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x280B0; sys_mmr.o(.MMR0xE00280B0)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x280B4; sys_mmr.o(.MMR0xE00280B4)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C000; sys_mmr.o(.MMR0xE002C000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C004; sys_mmr.o(.MMR0xE002C004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C008; sys_mmr.o(.MMR0xE002C008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C00C; sys_mmr.o(.MMR0xE002C00C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C010; sys_mmr.o(.MMR0xE002C010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C014; sys_mmr.o(.MMR0xE002C014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C018; sys_mmr.o(.MMR0xE002C018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C01C; sys_mmr.o(.MMR0xE002C01C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C020; sys_mmr.o(.MMR0xE002C020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C024; sys_mmr.o(.MMR0xE002C024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C028; sys_mmr.o(.MMR0xE002C028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C040; sys_mmr.o(.MMR0xE002C040)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C044; sys_mmr.o(.MMR0xE002C044)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C048; sys_mmr.o(.MMR0xE002C048)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C04C; sys_mmr.o(.MMR0xE002C04C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C050; sys_mmr.o(.MMR0xE002C050)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C054; sys_mmr.o(.MMR0xE002C054)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C058; sys_mmr.o(.MMR0xE002C058)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C05C; sys_mmr.o(.MMR0xE002C05C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C060; sys_mmr.o(.MMR0xE002C060)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x2C064; sys_mmr.o(.MMR0xE002C064)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x30000; sys_mmr.o(.MMR0xE0030000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x30004; sys_mmr.o(.MMR0xE0030004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x30008; sys_mmr.o(.MMR0xE0030008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x3000C; sys_mmr.o(.MMR0xE003000C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x30010; sys_mmr.o(.MMR0xE0030010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x30014; sys_mmr.o(.MMR0xE0030014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x30018; sys_mmr.o(.MMR0xE0030018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x3001C; sys_mmr.o(.MMR0xE003001C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x30020; sys_mmr.o(.MMR0xE0030020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x30024; sys_mmr.o(.MMR0xE0030024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x34000; sys_mmr.o(.MMR0xE0034000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x34004; sys_mmr.o(.MMR0xE0034004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x3400C; sys_mmr.o(.MMR0xE003400C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x34010; sys_mmr.o(.MMR0xE0034010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x34014; sys_mmr.o(.MMR0xE0034014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x34018; sys_mmr.o(.MMR0xE0034018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x3401C; sys_mmr.o(.MMR0xE003401C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x34020; sys_mmr.o(.MMR0xE0034020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x34024; sys_mmr.o(.MMR0xE0034024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x34028; sys_mmr.o(.MMR0xE0034028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x3402C; sys_mmr.o(.MMR0xE003402C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x34030; sys_mmr.o(.MMR0xE0034030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x3C000; sys_mmr.o(.MMR0xE003C000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x3C004; sys_mmr.o(.MMR0xE003C004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x3C008; sys_mmr.o(.MMR0xE003C008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x3C00C; sys_mmr.o(.MMR0xE003C00C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x3C010; sys_mmr.o(.MMR0xE003C010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x3C014; sys_mmr.o(.MMR0xE003C014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x3C018; sys_mmr.o(.MMR0xE003C018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x3C01C; sys_mmr.o(.MMR0xE003C01C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x40000; sys_mmr.o(.MMR0xE0040000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x40004; sys_mmr.o(.MMR0xE0040004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x40008; sys_mmr.o(.MMR0xE0040008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44000; sys_mmr.o(.MMR0xE0044000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44004; sys_mmr.o(.MMR0xE0044004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44008; sys_mmr.o(.MMR0xE0044008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4400C; sys_mmr.o(.MMR0xE004400C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44010; sys_mmr.o(.MMR0xE0044010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44014; sys_mmr.o(.MMR0xE0044014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44018; sys_mmr.o(.MMR0xE0044018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4401C; sys_mmr.o(.MMR0xE004401C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44020; sys_mmr.o(.MMR0xE0044020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44024; sys_mmr.o(.MMR0xE0044024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44028; sys_mmr.o(.MMR0xE0044028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4402C; sys_mmr.o(.MMR0xE004402C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44030; sys_mmr.o(.MMR0xE0044030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44034; sys_mmr.o(.MMR0xE0044034)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44038; sys_mmr.o(.MMR0xE0044038)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4403C; sys_mmr.o(.MMR0xE004403C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44040; sys_mmr.o(.MMR0xE0044040)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44044; sys_mmr.o(.MMR0xE0044044)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44048; sys_mmr.o(.MMR0xE0044048)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4404C; sys_mmr.o(.MMR0xE004404C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44050; sys_mmr.o(.MMR0xE0044050)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44054; sys_mmr.o(.MMR0xE0044054)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x44058; sys_mmr.o(.MMR0xE0044058)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4405C; sys_mmr.o(.MMR0xE004405C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48000; sys_mmr.o(.MMR0xE0048000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48004; sys_mmr.o(.MMR0xE0048004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48008; sys_mmr.o(.MMR0xE0048008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4800C; sys_mmr.o(.MMR0xE004800C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48010; sys_mmr.o(.MMR0xE0048010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48014; sys_mmr.o(.MMR0xE0048014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48018; sys_mmr.o(.MMR0xE0048018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4801C; sys_mmr.o(.MMR0xE004801C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48020; sys_mmr.o(.MMR0xE0048020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48024; sys_mmr.o(.MMR0xE0048024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48028; sys_mmr.o(.MMR0xE0048028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4802C; sys_mmr.o(.MMR0xE004802C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48030; sys_mmr.o(.MMR0xE0048030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48034; sys_mmr.o(.MMR0xE0048034)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48038; sys_mmr.o(.MMR0xE0048038)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4803C; sys_mmr.o(.MMR0xE004803C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48040; sys_mmr.o(.MMR0xE0048040)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48044; sys_mmr.o(.MMR0xE0048044)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48048; sys_mmr.o(.MMR0xE0048048)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4804C; sys_mmr.o(.MMR0xE004804C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48050; sys_mmr.o(.MMR0xE0048050)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48054; sys_mmr.o(.MMR0xE0048054)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x48058; sys_mmr.o(.MMR0xE0048058)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x4805C; sys_mmr.o(.MMR0xE004805C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x5C000; sys_mmr.o(.MMR0xE005C000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x5C004; sys_mmr.o(.MMR0xE005C004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x5C008; sys_mmr.o(.MMR0xE005C008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x5C00C; sys_mmr.o(.MMR0xE005C00C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x5C010; sys_mmr.o(.MMR0xE005C010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x5C014; sys_mmr.o(.MMR0xE005C014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x5C018; sys_mmr.o(.MMR0xE005C018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x68000; sys_mmr.o(.MMR0xE0068000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x68004; sys_mmr.o(.MMR0xE0068004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x68008; sys_mmr.o(.MMR0xE0068008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x6800C; sys_mmr.o(.MMR0xE006800C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x68010; sys_mmr.o(.MMR0xE0068010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x68014; sys_mmr.o(.MMR0xE0068014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x68018; sys_mmr.o(.MMR0xE0068018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x6801C; sys_mmr.o(.MMR0xE006801C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x68020; sys_mmr.o(.MMR0xE0068020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x68024; sys_mmr.o(.MMR0xE0068024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x6C000; sys_mmr.o(.MMR0xE006C000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x70000; sys_mmr.o(.MMR0xE0070000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x70004; sys_mmr.o(.MMR0xE0070004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x70008; sys_mmr.o(.MMR0xE0070008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7000C; sys_mmr.o(.MMR0xE007000C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x70010; sys_mmr.o(.MMR0xE0070010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x70014; sys_mmr.o(.MMR0xE0070014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x70018; sys_mmr.o(.MMR0xE0070018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7001C; sys_mmr.o(.MMR0xE007001C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x70020; sys_mmr.o(.MMR0xE0070020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x70024; sys_mmr.o(.MMR0xE0070024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x70028; sys_mmr.o(.MMR0xE0070028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7002C; sys_mmr.o(.MMR0xE007002C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x70030; sys_mmr.o(.MMR0xE0070030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x70034; sys_mmr.o(.MMR0xE0070034)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x70038; sys_mmr.o(.MMR0xE0070038)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7003C; sys_mmr.o(.MMR0xE007003C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x70070; sys_mmr.o(.MMR0xE0070070)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x74000; sys_mmr.o(.MMR0xE0074000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x74004; sys_mmr.o(.MMR0xE0074004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x74008; sys_mmr.o(.MMR0xE0074008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7400C; sys_mmr.o(.MMR0xE007400C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x74010; sys_mmr.o(.MMR0xE0074010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x74014; sys_mmr.o(.MMR0xE0074014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x74018; sys_mmr.o(.MMR0xE0074018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7401C; sys_mmr.o(.MMR0xE007401C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x74020; sys_mmr.o(.MMR0xE0074020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x74024; sys_mmr.o(.MMR0xE0074024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x74028; sys_mmr.o(.MMR0xE0074028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7402C; sys_mmr.o(.MMR0xE007402C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x74030; sys_mmr.o(.MMR0xE0074030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x74034; sys_mmr.o(.MMR0xE0074034)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x74038; sys_mmr.o(.MMR0xE0074038)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7403C; sys_mmr.o(.MMR0xE007403C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x74070; sys_mmr.o(.MMR0xE0074070)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x78000; sys_mmr.o(.MMR0xE0078000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x78004; sys_mmr.o(.MMR0xE0078004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x78008; sys_mmr.o(.MMR0xE0078008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7800C; sys_mmr.o(.MMR0xE007800C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x78014; sys_mmr.o(.MMR0xE0078014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7801C; sys_mmr.o(.MMR0xE007801C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x78020; sys_mmr.o(.MMR0xE0078020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x78024; sys_mmr.o(.MMR0xE0078024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x78028; sys_mmr.o(.MMR0xE0078028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x78030; sys_mmr.o(.MMR0xE0078030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7C000; sys_mmr.o(.MMR0xE007C000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7C004; sys_mmr.o(.MMR0xE007C004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7C008; sys_mmr.o(.MMR0xE007C008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7C00C; sys_mmr.o(.MMR0xE007C00C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7C014; sys_mmr.o(.MMR0xE007C014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7C01C; sys_mmr.o(.MMR0xE007C01C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7C020; sys_mmr.o(.MMR0xE007C020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7C024; sys_mmr.o(.MMR0xE007C024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7C028; sys_mmr.o(.MMR0xE007C028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x7C030; sys_mmr.o(.MMR0xE007C030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x80000; sys_mmr.o(.MMR0xE0080000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x80004; sys_mmr.o(.MMR0xE0080004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x80008; sys_mmr.o(.MMR0xE0080008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8000C; sys_mmr.o(.MMR0xE008000C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x80010; sys_mmr.o(.MMR0xE0080010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x80014; sys_mmr.o(.MMR0xE0080014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x80018; sys_mmr.o(.MMR0xE0080018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x88000; sys_mmr.o(.MMR0xE0088000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x88004; sys_mmr.o(.MMR0xE0088004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x88008; sys_mmr.o(.MMR0xE0088008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8800C; sys_mmr.o(.MMR0xE008800C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x88010; sys_mmr.o(.MMR0xE0088010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x88014; sys_mmr.o(.MMR0xE0088014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x88018; sys_mmr.o(.MMR0xE0088018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8801C; sys_mmr.o(.MMR0xE008801C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x88020; sys_mmr.o(.MMR0xE0088020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x88024; sys_mmr.o(.MMR0xE0088024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C000; sys_mmr.o(.MMR0xE008C000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C004; sys_mmr.o(.MMR0xE008C004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C008; sys_mmr.o(.MMR0xE008C008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C00C; sys_mmr.o(.MMR0xE008C00C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C010; sys_mmr.o(.MMR0xE008C010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C014; sys_mmr.o(.MMR0xE008C014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C018; sys_mmr.o(.MMR0xE008C018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C01C; sys_mmr.o(.MMR0xE008C01C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C020; sys_mmr.o(.MMR0xE008C020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C024; sys_mmr.o(.MMR0xE008C024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C028; sys_mmr.o(.MMR0xE008C028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C02C; sys_mmr.o(.MMR0xE008C02C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C030; sys_mmr.o(.MMR0xE008C030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C034; sys_mmr.o(.MMR0xE008C034)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C038; sys_mmr.o(.MMR0xE008C038)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C03C; sys_mmr.o(.MMR0xE008C03C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C040; sys_mmr.o(.MMR0xE008C040)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C048; sys_mmr.o(.MMR0xE008C048)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x8C080; sys_mmr.o(.MMR0xE008C080)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC000; sys_mmr.o(.MMR0xE01FC000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC004; sys_mmr.o(.MMR0xE01FC004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC040; sys_mmr.o(.MMR0xE01FC040)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC080; sys_mmr.o(.MMR0xE01FC080)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC084; sys_mmr.o(.MMR0xE01FC084)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC088; sys_mmr.o(.MMR0xE01FC088)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC08C; sys_mmr.o(.MMR0xE01FC08C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC0C0; sys_mmr.o(.MMR0xE01FC0C0)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC0C4; sys_mmr.o(.MMR0xE01FC0C4)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC104; sys_mmr.o(.MMR0xE01FC104)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC108; sys_mmr.o(.MMR0xE01FC108)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC10C; sys_mmr.o(.MMR0xE01FC10C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC140; sys_mmr.o(.MMR0xE01FC140)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC144; sys_mmr.o(.MMR0xE01FC144)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC148; sys_mmr.o(.MMR0xE01FC148)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC14C; sys_mmr.o(.MMR0xE01FC14C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC180; sys_mmr.o(.MMR0xE01FC180)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC184; sys_mmr.o(.MMR0xE01FC184)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC188; sys_mmr.o(.MMR0xE01FC188)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC18C; sys_mmr.o(.MMR0xE01FC18C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC1A0; sys_mmr.o(.MMR0xE01FC1A0)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC1A8; sys_mmr.o(.MMR0xE01FC1A8)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC1AC; sys_mmr.o(.MMR0xE01FC1AC)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FC1C0; sys_mmr.o(.MMR0xE01FC1C0)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00000; sys_mmr.o(.MMR0xFFE00000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00004; sys_mmr.o(.MMR0xFFE00004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00008; sys_mmr.o(.MMR0xFFE00008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0000C; sys_mmr.o(.MMR0xFFE0000C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00010; sys_mmr.o(.MMR0xFFE00010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00014; sys_mmr.o(.MMR0xFFE00014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00018; sys_mmr.o(.MMR0xFFE00018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0001C; sys_mmr.o(.MMR0xFFE0001C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00020; sys_mmr.o(.MMR0xFFE00020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00024; sys_mmr.o(.MMR0xFFE00024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00028; sys_mmr.o(.MMR0xFFE00028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0002C; sys_mmr.o(.MMR0xFFE0002C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00030; sys_mmr.o(.MMR0xFFE00030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00034; sys_mmr.o(.MMR0xFFE00034)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00040; sys_mmr.o(.MMR0xFFE00040)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00044; sys_mmr.o(.MMR0xFFE00044)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00048; sys_mmr.o(.MMR0xFFE00048)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00100; sys_mmr.o(.MMR0xFFE00100)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00104; sys_mmr.o(.MMR0xFFE00104)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00108; sys_mmr.o(.MMR0xFFE00108)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0010C; sys_mmr.o(.MMR0xFFE0010C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00110; sys_mmr.o(.MMR0xFFE00110)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00114; sys_mmr.o(.MMR0xFFE00114)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00118; sys_mmr.o(.MMR0xFFE00118)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0011C; sys_mmr.o(.MMR0xFFE0011C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00120; sys_mmr.o(.MMR0xFFE00120)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00124; sys_mmr.o(.MMR0xFFE00124)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00128; sys_mmr.o(.MMR0xFFE00128)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0012C; sys_mmr.o(.MMR0xFFE0012C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00158; sys_mmr.o(.MMR0xFFE00158)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0015C; sys_mmr.o(.MMR0xFFE0015C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00160; sys_mmr.o(.MMR0xFFE00160)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00170; sys_mmr.o(.MMR0xFFE00170)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00174; sys_mmr.o(.MMR0xFFE00174)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00200; sys_mmr.o(.MMR0xFFE00200)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00204; sys_mmr.o(.MMR0xFFE00204)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00208; sys_mmr.o(.MMR0xFFE00208)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00210; sys_mmr.o(.MMR0xFFE00210)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00214; sys_mmr.o(.MMR0xFFE00214)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00FE0; sys_mmr.o(.MMR0xFFE00FE0)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00FE4; sys_mmr.o(.MMR0xFFE00FE4)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00FE8; sys_mmr.o(.MMR0xFFE00FE8)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00FEC; sys_mmr.o(.MMR0xFFE00FEC)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00FF4; sys_mmr.o(.MMR0xFFE00FF4)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE00FFC; sys_mmr.o(.MMR0xFFE00FFC)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04000; sys_mmr.o(.MMR0xFFE04000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04004; sys_mmr.o(.MMR0xFFE04004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04008; sys_mmr.o(.MMR0xFFE04008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0400C; sys_mmr.o(.MMR0xFFE0400C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04010; sys_mmr.o(.MMR0xFFE04010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04014; sys_mmr.o(.MMR0xFFE04014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04018; sys_mmr.o(.MMR0xFFE04018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0401C; sys_mmr.o(.MMR0xFFE0401C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04020; sys_mmr.o(.MMR0xFFE04020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04024; sys_mmr.o(.MMR0xFFE04024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04028; sys_mmr.o(.MMR0xFFE04028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0402C; sys_mmr.o(.MMR0xFFE0402C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04030; sys_mmr.o(.MMR0xFFE04030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04034; sys_mmr.o(.MMR0xFFE04034)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04100; sys_mmr.o(.MMR0xFFE04100)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04104; sys_mmr.o(.MMR0xFFE04104)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04108; sys_mmr.o(.MMR0xFFE04108)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0410C; sys_mmr.o(.MMR0xFFE0410C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04110; sys_mmr.o(.MMR0xFFE04110)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04120; sys_mmr.o(.MMR0xFFE04120)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04124; sys_mmr.o(.MMR0xFFE04124)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04128; sys_mmr.o(.MMR0xFFE04128)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0412C; sys_mmr.o(.MMR0xFFE0412C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE04130; sys_mmr.o(.MMR0xFFE04130)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08000; sys_mmr.o(.MMR0xFFE08000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08004; sys_mmr.o(.MMR0xFFE08004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08008; sys_mmr.o(.MMR0xFFE08008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08020; sys_mmr.o(.MMR0xFFE08020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08024; sys_mmr.o(.MMR0xFFE08024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08028; sys_mmr.o(.MMR0xFFE08028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08030; sys_mmr.o(.MMR0xFFE08030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08034; sys_mmr.o(.MMR0xFFE08034)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08038; sys_mmr.o(.MMR0xFFE08038)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0803C; sys_mmr.o(.MMR0xFFE0803C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08040; sys_mmr.o(.MMR0xFFE08040)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08044; sys_mmr.o(.MMR0xFFE08044)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08048; sys_mmr.o(.MMR0xFFE08048)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0804C; sys_mmr.o(.MMR0xFFE0804C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08050; sys_mmr.o(.MMR0xFFE08050)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08054; sys_mmr.o(.MMR0xFFE08054)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08058; sys_mmr.o(.MMR0xFFE08058)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08080; sys_mmr.o(.MMR0xFFE08080)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08100; sys_mmr.o(.MMR0xFFE08100)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08104; sys_mmr.o(.MMR0xFFE08104)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08120; sys_mmr.o(.MMR0xFFE08120)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08124; sys_mmr.o(.MMR0xFFE08124)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08140; sys_mmr.o(.MMR0xFFE08140)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08144; sys_mmr.o(.MMR0xFFE08144)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08160; sys_mmr.o(.MMR0xFFE08160)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08164; sys_mmr.o(.MMR0xFFE08164)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08200; sys_mmr.o(.MMR0xFFE08200)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08204; sys_mmr.o(.MMR0xFFE08204)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08208; sys_mmr.o(.MMR0xFFE08208)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0820C; sys_mmr.o(.MMR0xFFE0820C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08210; sys_mmr.o(.MMR0xFFE08210)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08214; sys_mmr.o(.MMR0xFFE08214)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08218; sys_mmr.o(.MMR0xFFE08218)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08220; sys_mmr.o(.MMR0xFFE08220)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08224; sys_mmr.o(.MMR0xFFE08224)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08228; sys_mmr.o(.MMR0xFFE08228)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0822C; sys_mmr.o(.MMR0xFFE0822C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08230; sys_mmr.o(.MMR0xFFE08230)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08234; sys_mmr.o(.MMR0xFFE08234)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08238; sys_mmr.o(.MMR0xFFE08238)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08240; sys_mmr.o(.MMR0xFFE08240)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08244; sys_mmr.o(.MMR0xFFE08244)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08248; sys_mmr.o(.MMR0xFFE08248)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0824C; sys_mmr.o(.MMR0xFFE0824C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08250; sys_mmr.o(.MMR0xFFE08250)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08254; sys_mmr.o(.MMR0xFFE08254)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08258; sys_mmr.o(.MMR0xFFE08258)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08260; sys_mmr.o(.MMR0xFFE08260)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08264; sys_mmr.o(.MMR0xFFE08264)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08268; sys_mmr.o(.MMR0xFFE08268)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0826C; sys_mmr.o(.MMR0xFFE0826C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08270; sys_mmr.o(.MMR0xFFE08270)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08274; sys_mmr.o(.MMR0xFFE08274)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE08278; sys_mmr.o(.MMR0xFFE08278)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C000; sys_mmr.o(.MMR0xFFE0C000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C004; sys_mmr.o(.MMR0xFFE0C004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C008; sys_mmr.o(.MMR0xFFE0C008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C00C; sys_mmr.o(.MMR0xFFE0C00C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C010; sys_mmr.o(.MMR0xFFE0C010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C014; sys_mmr.o(.MMR0xFFE0C014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C018; sys_mmr.o(.MMR0xFFE0C018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C01C; sys_mmr.o(.MMR0xFFE0C01C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C020; sys_mmr.o(.MMR0xFFE0C020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C024; sys_mmr.o(.MMR0xFFE0C024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C028; sys_mmr.o(.MMR0xFFE0C028)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C02C; sys_mmr.o(.MMR0xFFE0C02C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C030; sys_mmr.o(.MMR0xFFE0C030)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C034; sys_mmr.o(.MMR0xFFE0C034)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C038; sys_mmr.o(.MMR0xFFE0C038)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C03C; sys_mmr.o(.MMR0xFFE0C03C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C040; sys_mmr.o(.MMR0xFFE0C040)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C044; sys_mmr.o(.MMR0xFFE0C044)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C048; sys_mmr.o(.MMR0xFFE0C048)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C04C; sys_mmr.o(.MMR0xFFE0C04C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C050; sys_mmr.o(.MMR0xFFE0C050)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C054; sys_mmr.o(.MMR0xFFE0C054)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C058; sys_mmr.o(.MMR0xFFE0C058)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C100; sys_mmr.o(.MMR0xFFE0C100)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C104; sys_mmr.o(.MMR0xFFE0C104)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C108; sys_mmr.o(.MMR0xFFE0C108)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C10C; sys_mmr.o(.MMR0xFFE0C10C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C110; sys_mmr.o(.MMR0xFFE0C110)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C114; sys_mmr.o(.MMR0xFFE0C114)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C200; sys_mmr.o(.MMR0xFFE0C200)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C204; sys_mmr.o(.MMR0xFFE0C204)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C208; sys_mmr.o(.MMR0xFFE0C208)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C20C; sys_mmr.o(.MMR0xFFE0C20C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C210; sys_mmr.o(.MMR0xFFE0C210)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C214; sys_mmr.o(.MMR0xFFE0C214)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C218; sys_mmr.o(.MMR0xFFE0C218)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C21C; sys_mmr.o(.MMR0xFFE0C21C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C220; sys_mmr.o(.MMR0xFFE0C220)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C224; sys_mmr.o(.MMR0xFFE0C224)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C228; sys_mmr.o(.MMR0xFFE0C228)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C22C; sys_mmr.o(.MMR0xFFE0C22C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C230; sys_mmr.o(.MMR0xFFE0C230)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C234; sys_mmr.o(.MMR0xFFE0C234)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C238; sys_mmr.o(.MMR0xFFE0C238)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C23C; sys_mmr.o(.MMR0xFFE0C23C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C240; sys_mmr.o(.MMR0xFFE0C240)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C244; sys_mmr.o(.MMR0xFFE0C244)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C248; sys_mmr.o(.MMR0xFFE0C248)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C24C; sys_mmr.o(.MMR0xFFE0C24C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C250; sys_mmr.o(.MMR0xFFE0C250)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C254; sys_mmr.o(.MMR0xFFE0C254)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C258; sys_mmr.o(.MMR0xFFE0C258)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C280; sys_mmr.o(.MMR0xFFE0C280)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C284; sys_mmr.o(.MMR0xFFE0C284)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C288; sys_mmr.o(.MMR0xFFE0C288)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C28C; sys_mmr.o(.MMR0xFFE0C28C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C290; sys_mmr.o(.MMR0xFFE0C290)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C294; sys_mmr.o(.MMR0xFFE0C294)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C2A0; sys_mmr.o(.MMR0xFFE0C2A0)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C2A4; sys_mmr.o(.MMR0xFFE0C2A4)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C2A8; sys_mmr.o(.MMR0xFFE0C2A8)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C2AC; sys_mmr.o(.MMR0xFFE0C2AC)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C2B0; sys_mmr.o(.MMR0xFFE0C2B0)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C2B4; sys_mmr.o(.MMR0xFFE0C2B4)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C2B8; sys_mmr.o(.MMR0xFFE0C2B8)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C2BC; sys_mmr.o(.MMR0xFFE0C2BC)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C2C0; sys_mmr.o(.MMR0xFFE0C2C0)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C300; sys_mmr.o(.MMR0xFFE0C300)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C304; sys_mmr.o(.MMR0xFFE0C304)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C308; sys_mmr.o(.MMR0xFFE0C308)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C30C; sys_mmr.o(.MMR0xFFE0C30C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0C310; sys_mmr.o(.MMR0xFFE0C310)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0CFF4; sys_mmr.o(.MMR0xFFE0CFF4)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FE0CFF8; sys_mmr.o(.MMR0xFFE0CFF8)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF000; sys_mmr.o(.MMR0xFFFFF000)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF004; sys_mmr.o(.MMR0xFFFFF004)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF008; sys_mmr.o(.MMR0xFFFFF008)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF00C; sys_mmr.o(.MMR0xFFFFF00C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF010; sys_mmr.o(.MMR0xFFFFF010)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF014; sys_mmr.o(.MMR0xFFFFF014)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF018; sys_mmr.o(.MMR0xFFFFF018)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF01C; sys_mmr.o(.MMR0xFFFFF01C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF020; sys_mmr.o(.MMR0xFFFFF020)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF024; sys_mmr.o(.MMR0xFFFFF024)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF100; sys_mmr.o(.MMR0xFFFFF100)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF104; sys_mmr.o(.MMR0xFFFFF104)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF108; sys_mmr.o(.MMR0xFFFFF108)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF10C; sys_mmr.o(.MMR0xFFFFF10C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF110; sys_mmr.o(.MMR0xFFFFF110)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF114; sys_mmr.o(.MMR0xFFFFF114)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF118; sys_mmr.o(.MMR0xFFFFF118)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF11C; sys_mmr.o(.MMR0xFFFFF11C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF120; sys_mmr.o(.MMR0xFFFFF120)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF124; sys_mmr.o(.MMR0xFFFFF124)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF128; sys_mmr.o(.MMR0xFFFFF128)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF12C; sys_mmr.o(.MMR0xFFFFF12C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF130; sys_mmr.o(.MMR0xFFFFF130)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF134; sys_mmr.o(.MMR0xFFFFF134)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF138; sys_mmr.o(.MMR0xFFFFF138)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF13C; sys_mmr.o(.MMR0xFFFFF13C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF140; sys_mmr.o(.MMR0xFFFFF140)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF144; sys_mmr.o(.MMR0xFFFFF144)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF148; sys_mmr.o(.MMR0xFFFFF148)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF14C; sys_mmr.o(.MMR0xFFFFF14C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF150; sys_mmr.o(.MMR0xFFFFF150)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF154; sys_mmr.o(.MMR0xFFFFF154)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF158; sys_mmr.o(.MMR0xFFFFF158)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF15C; sys_mmr.o(.MMR0xFFFFF15C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF160; sys_mmr.o(.MMR0xFFFFF160)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF164; sys_mmr.o(.MMR0xFFFFF164)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF168; sys_mmr.o(.MMR0xFFFFF168)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF16C; sys_mmr.o(.MMR0xFFFFF16C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF170; sys_mmr.o(.MMR0xFFFFF170)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF174; sys_mmr.o(.MMR0xFFFFF174)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF178; sys_mmr.o(.MMR0xFFFFF178)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF17C; sys_mmr.o(.MMR0xFFFFF17C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF200; sys_mmr.o(.MMR0xFFFFF200)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF204; sys_mmr.o(.MMR0xFFFFF204)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF208; sys_mmr.o(.MMR0xFFFFF208)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF20C; sys_mmr.o(.MMR0xFFFFF20C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF210; sys_mmr.o(.MMR0xFFFFF210)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF214; sys_mmr.o(.MMR0xFFFFF214)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF218; sys_mmr.o(.MMR0xFFFFF218)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF21C; sys_mmr.o(.MMR0xFFFFF21C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF220; sys_mmr.o(.MMR0xFFFFF220)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF224; sys_mmr.o(.MMR0xFFFFF224)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF228; sys_mmr.o(.MMR0xFFFFF228)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF22C; sys_mmr.o(.MMR0xFFFFF22C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF230; sys_mmr.o(.MMR0xFFFFF230)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF234; sys_mmr.o(.MMR0xFFFFF234)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF238; sys_mmr.o(.MMR0xFFFFF238)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF23C; sys_mmr.o(.MMR0xFFFFF23C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF240; sys_mmr.o(.MMR0xFFFFF240)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF244; sys_mmr.o(.MMR0xFFFFF244)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF248; sys_mmr.o(.MMR0xFFFFF248)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF24C; sys_mmr.o(.MMR0xFFFFF24C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF250; sys_mmr.o(.MMR0xFFFFF250)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF254; sys_mmr.o(.MMR0xFFFFF254)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF258; sys_mmr.o(.MMR0xFFFFF258)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF25C; sys_mmr.o(.MMR0xFFFFF25C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF260; sys_mmr.o(.MMR0xFFFFF260)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF264; sys_mmr.o(.MMR0xFFFFF264)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF268; sys_mmr.o(.MMR0xFFFFF268)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF26C; sys_mmr.o(.MMR0xFFFFF26C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF270; sys_mmr.o(.MMR0xFFFFF270)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF274; sys_mmr.o(.MMR0xFFFFF274)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF278; sys_mmr.o(.MMR0xFFFFF278)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFF27C; sys_mmr.o(.MMR0xFFFFF27C)} > MEM_SYS
	.bss.sysmmr (NOLOAD) : { . = 0x1FFFFF00; sys_mmr.o(.MMR0xFFFFFF00)} > MEM_SYS
}	

	
		
	